@@ -7,7 +7,7 @@ from selenium.webdriver.support.expected_conditions import presence_of_element_l
 from selenium.webdriver.support.wait import WebDriverWait
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions as EC
-from selenium.common.exceptions import NoSuchElementException, TimeoutException        
+from selenium.common.exceptions import ElementClickInterceptedException, NoSuchElementException, TimeoutException        
 import time, os
 
 from instaclient.utilities.utilities import *
@@ -126,7 +126,6 @@ class InstaClient:
             # Get Form elements
             username_input = self.__find_element(EC.presence_of_element_located((By.XPATH,Paths.USERNAME_INPUT)), url=ClientUrls.LOGIN_URL)
             password_input = self.__find_element(EC.presence_of_element_located((By.XPATH,Paths.PASSWORD_INPUT)), url=ClientUrls.LOGIN_URL)
-            login_btn = self.__find_element(EC.presence_of_element_located((By.XPATH,Paths.LOGIN_BTN)), url=ClientUrls.LOGIN_URL)# login button xpath changes after text is entered, find first
             print('INSTACLIENT: Found elements')
             # Fill out form
             username_input.send_keys(username)
@@ -134,8 +133,13 @@ class InstaClient:
             password_input.send_keys(password)
             time.sleep(1)
             print('INSTACLIENT: Filled in form')
+            login_btn = self.__find_element(EC.presence_of_element_located((By.XPATH,Paths.LOGIN_BTN)), url=ClientUrls.LOGIN_URL)# login button xpath changes after text is entered, find first
             login_btn.click()
             print('INSTACLIENT: Sent form')
+        except ElementClickInterceptedException as error:
+            self.password = None
+            self.driver.get(ClientUrls.LOGIN_URL)
+            raise InvaildPasswordError(password)
         except Exception as error:
             # User already logged in ?
             result = self.check_status()
